@@ -1,10 +1,11 @@
-from .borders import Borders, BorderDfn
+from .borders import Bdr
 from .card import Card
 from .fill import Fill
 from .flex import Flex
 from .hr import HR
 from .line import Line
 from .pretty import pretty
+from .pretty_exception import PrettyException
 from .printer import Printer
 from .table import Table, CellDfn
 from .text import Text
