@@ -1,6 +1,6 @@
 from .flex import Flex
 from .hr import HR
-from .borders import Borders, BorderDfn
+from .borders import Bdr
 from .context import Context
 
 
@@ -28,7 +28,7 @@ class Card(Flex, border='-', border_style='dem'):
         super().__init__(**kwargs)
         self.title = HR(parent=self, just='_', width_max=0) # FIXME: We need a way to stop propagation
         self._filling_title = True
-        self.body = Borders(border=(' ','m:01'))
+        self.body = Bdr(border=(' ','m:01'))
         self(*args)
 
 
@@ -57,14 +57,12 @@ class Card(Flex, border='-', border_style='dem'):
         w = w or self.width
         bdr = self['border']
         t = bdr.c[0]+bdr.t[1:3]+bdr.c[1]+bdr.t[4]+  bdr.c[4]+bdr.t[6:8]+bdr.c[5]+bdr.t[9]
-        l = bdr.l[0:4] + BorderDfn.join(BorderDfn.ext(bdr.l[2] + ' ' + bdr.l[2] + bdr.t[2])) + bdr.l[5:10]
-        r = bdr.r[0:4] + BorderDfn.join(BorderDfn.ext(bdr.l[2] + bdr.t[2] + bdr.l[2] + ' ')) + bdr.r[5:10]
-        self.title['border'] = BorderDfn(bdr, t=t, l=l, r=r)
+        self.title['border'] = Bdr.dfn(bdr, t=t)
         title = list(self.title.flatten(w=w,h=0,**kwargs))
         h = h or self['height_max'] or 0
         if h and h > 2 and len(title) + 2 > h: title = list(self.title.flatten(w=w,h=1,**kwargs))
         if h: h -= len(title)
         yield from title
-        body = Borders(self.body, parent=self, border=('m:0111'))
+        body = Bdr(self.body, parent=self, border=('m:0111'))
         yield from body.flatten(w=w, h=h, **kwargs)
         
\ No newline at end of file
