@@ -70,6 +70,34 @@ def test_hr_clone():
 
 
 def test_hr_infinity():
-    o,p = printer(ascii=True)
+    o,p = printer(ascii=True,color=False)
+    p(HR('\b1 hi'))
+    assert(o.getvalue() == '-[ hi ]-\n')
+    o.seek(0)
+    o.truncate()
     p.hr()
     assert(o.getvalue() == '---\n')
+
+
+def test_hr_joins():
+    o,p = printer(ascii=False,color=False)
+    p.hr('hi', border='=')
+    assert(o.getvalue() == '═╣ hi ╠═\n')
+
+
+def test_hr_joins_ascii():
+    o,p = printer(ascii=True,color=False)
+    p.hr('hi', border='=')
+    assert(o.getvalue() == '=# hi #=\n')
+
+
+def test_hr_joins_bold():
+    o,p = printer(ascii=False, color=False)
+    p.hr('hi', border=('#', '-.rl'))
+    assert(o.getvalue() == '━┥ hi ┝━\n')
+
+
+def test_hr_joins_double_space():
+    o,p = printer(ascii=False, color=False)
+    p.hr('hi', border=('=', ' .rl'))
+    assert(o.getvalue() == '═  hi  ═\n')
